@@ -30,7 +30,7 @@
 #' @param text.comparator A character string used in the plot to label
 #'   the comparator if \code{lump.comparator} is \code{TRUE}.
 #' @param method.bias A character vector indicating which test(s) for
-#'   funnel plot asymmatrx to use. Admissible values are
+#'   funnel plot asymmetry to use. Admissible values are
 #'   \code{"Begg"}, \code{"Egger"}, and \code{"Thompson"}, can be
 #'   abbreviated. See function \code{\link[meta]{metabias}}.
 #' @param text.linreg A character string used in the plot to label the
@@ -244,11 +244,16 @@ funnel.netmeta <- function(x,
   pooled[pooled == "fixed"] <- "common"
   chklogical(lump.comparator)
   ##
+  sfsp <- sys.frame(sys.parent())
+  mc <- match.call()
+  ##
   if (missing(order))
     stop("Argument 'order' with a meaningful order of treatments ",
          "must be provided.\n  ",
          "(see help page of funnel.netmeta for some examples).")
   else {
+    order <- catch("order", mc, x, sfsp)
+    ##
     if (length(order) != length(x$trts)) {
       order <- setchar(order, x$trts)
       order.all <- c(x$trts[!(x$trts %in% order)], order)
