@@ -30,6 +30,7 @@ updateversion <- function(x, verbose = FALSE) {
   update.1.3.0 <- update_needed(x$version, 1, 3, verbose)
   update.2.0.0 <- update_needed(x$version, 2, 0, verbose)
   update.2.5.0 <- update_needed(x$version, 2, 5, verbose)
+  update.2.8.0 <- update_needed(x$version, 2, 8, verbose)
   
   
   ##
@@ -169,6 +170,9 @@ updateversion <- function(x, verbose = FALSE) {
       x$Cov.common <- x$Cov.fixed               
     }
     ##
+    if (update.2.8.0)
+      x$small.values <- setsv(x$small.values)
+    ##
     return(x)
   }
   
@@ -190,6 +194,9 @@ updateversion <- function(x, verbose = FALSE) {
     if (update.2.5.0)
       x$x$common <- x$x$fixed
     ##
+    if (update.2.8.0)
+      x$x$small.values <- setsv(x$x$small.values)
+    ##
     return(x)
   }
   
@@ -270,6 +277,9 @@ updateversion <- function(x, verbose = FALSE) {
       x$H.matrix.common <- x$H.matrix.fixed        
     }
     ##
+    if (update.2.8.0)
+      x$x$small.values <- setsv(x$x$small.values)
+    ##
     return(x)
   }
   
@@ -396,6 +406,9 @@ updateversion <- function(x, verbose = FALSE) {
       x$compare.common <- x$compare.fixed
     }
     ##
+    if (update.2.8.0)
+      x$x$small.values <- setsv(x$x$small.values)
+    ##
     return(x)
   }
   
@@ -417,6 +430,9 @@ updateversion <- function(x, verbose = FALSE) {
       x$Pmatrix.common <- x$Pmatrix.fixed
     }
     ##
+    if (update.2.8.0)
+      x$small.values <- setsv(x$small.values)
+    ##
     return(x)
   }
   
@@ -447,6 +463,9 @@ updateversion <- function(x, verbose = FALSE) {
       x$cumrank.matrix.common <- x$cumrank.matrix.fixed
     }
     ##
+    if (update.2.8.0)
+      x$small.values <- setsv(x$small.values)
+    ##
     return(x)
   }
   
@@ -468,6 +487,9 @@ updateversion <- function(x, verbose = FALSE) {
       x$version <- packageDescription("netmeta")$Version
     }              
     ##
+    if (update.2.8.0)
+      x$x$small.values <- setsv(x$x$small.values)
+    ##
     return(x)
   }
   
@@ -521,6 +543,9 @@ updateversion <- function(x, verbose = FALSE) {
       x$version <- packageDescription("netmeta")$Version
     }              
     ##
+    if (update.2.8.0)
+      x$small.values <- setsv(x$small.values)
+    ##
     return(x)
   }
   
@@ -545,6 +570,9 @@ updateversion <- function(x, verbose = FALSE) {
         res$tictoc.common <- res$tictoc.fixed
     }
     ##
+    if (update.2.8.0)
+      x$x$small.values <- setsv(x$x$small.values)
+    ##
     return(x)
   }
   
@@ -566,6 +594,9 @@ updateversion <- function(x, verbose = FALSE) {
       x$version <- packageDescription("netmeta")$Version
     }
     ##
+    if (update.2.8.0)
+      x$x$small.values <- setsv(x$x$small.values)
+    ##
     return(x)
   }
   
@@ -587,6 +618,9 @@ updateversion <- function(x, verbose = FALSE) {
       x$version <- packageDescription("netmeta")$Version
     }
     ##
+    if (update.2.8.0)
+      x$x$small.values <- setsv(x$x$small.values)
+    ##
     return(x)
   }
   
